@@ -1,10 +1,12 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-import xml.sax
+from __future__ import absolute_import
+from __future__ import print_function
+import lxml.sax
 from lxml import etree
-from cStringIO import StringIO
-from content_handler import XUpdateHandler
+from six import StringIO
+from .content_handler import XUpdateHandler
 
 def applyXUpdate(xml_xu_file=None,
                  xml_doc_file=None,
@@ -26,16 +28,12 @@ def applyXUpdate(xml_xu_file=None,
   if xml_doc_filename:
     xml_doc = xml_doc_filename
   original_tree = etree.parse(xml_doc, etree_parser)
-  parser = xml.sax.make_parser()
-  parser.setFeature(xml.sax.handler.feature_namespaces, True)
-  parser.setFeature(xml.sax.handler.feature_namespace_prefixes, True)
-  parser.setContentHandler(XUpdateHandler(original_tree=original_tree))
-  parser.parse(xml_xu)
-  content_handler = parser.getContentHandler()
+  content_handler = XUpdateHandler(original_tree=original_tree)
+  lxml.sax.saxify(etree.parse(xml_xu, etree_parser), content_handler)
   return content_handler.result_tree
 
 if __name__ == '__main__':
   import sys
   doc_xml_name = sys.argv[1]
   xu_xml_name = sys.argv[2]
-  print etree.tostring(applyXUpdate(xml_xu_filename=xu_xml_name, xml_doc_filename=doc_xml_name), pretty_print=True)
+  print(etree.tostring(applyXUpdate(xml_xu_filename=xu_xml_name, xml_doc_filename=doc_xml_name), pretty_print=True))
